@@ -6,31 +6,31 @@
 #include <QAbstractListModel>
 #include <QSortFilterProxyModel>
 
-class FontListModel : public QAbstractListModel {
+class FontListModel : public QAbstractListModel
+{
     Q_OBJECT
-    
+
 public:
     static FontListModel *self();
-    
+
     explicit FontListModel(QObject *parent = nullptr);
-    
-    enum Roles {
-        NameRole = Qt::DisplayRole
-    };
+
+    enum Roles { NameRole = Qt::DisplayRole };
 
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
     QHash<int, QByteArray> roleNames() const override;
-    
+
 private:
     QStringList m_fontList;
 };
 
-class FontListSearchModel : public QSortFilterProxyModel {
+class FontListSearchModel : public QSortFilterProxyModel
+{
     Q_OBJECT
-    
+
 public:
     static FontListSearchModel *self();
-    
+
     explicit FontListSearchModel(QObject *parent = nullptr);
 };
